@@ -1,4 +1,6 @@
-from countergen.data_augmentation import augment_dataset, SimpleConverter
+from countergen.data_augmentation import augment_dataset, SimpleConverter, Dataset, AugmentedDataset
 from countergen.evaluation import evaluate
 from countergen.classification_models import get_huggingface_classification_model_evaluator
 from countergen.generative_models import get_huggingface_gpt_model_evaluator
+
+from countergen import *
